@@ -1,5 +1,5 @@
 document.getElementById("Contents").innerHTML='\
-    <ul><li><input type="checkbox" id="07"><label for="07">宏与编程</label><ul>\
+    <ul><li><input type="checkbox" id="07"><label for="07">宏与脚本</label><ul>\
     <li><input type="checkbox" id="0701"><label for="0701">一般信息及用户界面使用</label><ul>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/main0601.html">LibreOffice Basic 帮助</a></li>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/01000000.html">使用 LibreOffice Basic 编程</a></li>\
@@ -124,6 +124,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03090202.html">For...Next 语句</a></li>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03120301.html">Format Function</a></li>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03150000.html">FormatDateTime Function [VBA]</a></li>\
+    <li><a target="_top" href="zh-CN/text/sbasic/shared/03170010.html">FormatNumber Function [VBA]</a></li>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03020102.html">FreeFile 函数</a></li>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03090405.html">FreeLibrary 函数</a></li>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03090406.html">函数语句</a></li>\
@@ -271,7 +272,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03070400.html">"/" 操作符</a></li>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03070500.html">"^" 操作符</a></li>\
 			</ul></li>\
-    <li><input type="checkbox" id="070205"><label for="070205">Advanced Basic Libraries</label><ul>\
+    <li><input type="checkbox" id="070205"><label for="070205">高级 Basic 库</label><ul>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03/lib_tools.html">Tools Library</a></li>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03/lib_depot.html">DEPOT Library</a></li>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03/lib_euro.html">EURO Library</a></li>\
@@ -297,7 +298,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/sbasic/guide/access2base.html">Access2Base</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="08"><label for="08">电子表格</label><ul>\
+    <ul><li><input type="checkbox" id="08"><label for="08">电子表格 (Calc)</label><ul>\
     <li><input type="checkbox" id="0801"><label for="0801">一般信息及用户界面使用</label><ul>\
     <li><a target="_top" href="zh-CN/text/scalc/main0000.html">欢迎使用 LibreOffice Calc 帮助</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/main0503.html">LibreOffice Calc 电子表格的功能</a></li>\
@@ -477,7 +478,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/schart/04/01020000.html">图表的快捷键</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="01"><label for="01">安装</label><ul>\
+    <ul><li><input type="checkbox" id="01"><label for="01">LibreOffice 安装</label><ul>\
     <li><a target="_top" href="zh-CN/text/shared/guide/ms_doctypes.html">修改 Microsoft Office 文档类型的关联</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/01/profile_safe_mode.html">安全模式</a></li>\
 	</ul></li></ul>\
@@ -503,7 +504,6 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/shared/optionen/01010200.html">常规</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/optionen/01010300.html">路径</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/optionen/01010400.html">写作辅助</a></li>\
-    <li><a target="_top" href="zh-CN/text/shared/optionen/01010500.html">Color</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/optionen/01010600.html">常规</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/optionen/01010700.html">字体</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/optionen/01010800.html">视图</a></li>\
@@ -661,7 +661,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/shared/guide/numbering_stop.html">关闭单独段落的项目符号和编号</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="09"><label for="09">数据库功能</label><ul>\
+    <ul><li><input type="checkbox" id="09"><label for="09">数据库功能 (Base)</label><ul>\
     <li><input type="checkbox" id="0901"><label for="0901">一般信息</label><ul>\
     <li><a target="_top" href="zh-CN/text/shared/explorer/database/main.html">LibreOffice 数据库</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/database_main.html">数据库摘要</a></li>\
@@ -675,7 +675,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/shared/guide/data_enter_sql.html">执行 SQL 命令</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="04"><label for="04">演示文稿及绘图</label><ul>\
+    <ul><li><input type="checkbox" id="04"><label for="04">演示文稿与绘图 (Impress/Draw)</label><ul>\
     <li><input type="checkbox" id="0401"><label for="0401">一般信息及用户界面使用</label><ul>\
     <li><a target="_top" href="zh-CN/text/simpress/main0000.html">欢迎使用 LibreOffice Impress 帮助</a></li>\
     <li><a target="_top" href="zh-CN/text/sdraw/main0000.html">欢迎使用 LibreOffice Draw 帮助</a></li>\
@@ -820,7 +820,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/simpress/guide/rehearse_timings.html">幻灯片更换的排练计时</a></li>\
          </ul></li>\
      </ul></li></ul>\
-    <ul><li><input type="checkbox" id="03"><label for="03">公式</label><ul>\
+    <ul><li><input type="checkbox" id="03"><label for="03">公式 (Math)</label><ul>\
     <li><input type="checkbox" id="0301"><label for="0301">一般信息及用户界面使用</label><ul>\
     <li><a target="_top" href="zh-CN/text/smath/main0000.html">欢迎使用 LibreOffice Math 帮助</a></li>\
     <li><a target="_top" href="zh-CN/text/smath/main0503.html">LibreOffice Math 功能</a></li>\
@@ -840,7 +840,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/smath/guide/parentheses.html">插入括号</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="02"><label for="02">文本文档</label><ul>\
+    <ul><li><input type="checkbox" id="02"><label for="02">文本文档 (Writer)</label><ul>\
     <li><input type="checkbox" id="0201"><label for="0201">一般信息及用户界面使用</label><ul>\
     <li><a target="_top" href="zh-CN/text/swriter/main0000.html">欢迎使用 LibreOffice Writer 文本文档帮助</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/main0503.html">LibreOffice Writer 的主要功能</a></li>\
@@ -918,7 +918,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/swriter/guide/section_edit.html">编辑区域</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/section_insert.html">插入区域</a></li>\
 		</ul></li>\
-    <li><input type="checkbox" id="0208"><label for="0208">内容目录和索引</label><ul>\
+    <li><input type="checkbox" id="0208"><label for="0208">目录与索引</label><ul>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/chapter_numbering.html">章节编号</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/indices_userdef.html">自定义索引</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/indices_toc.html">创建目录</a></li>\
@@ -1002,7 +1002,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/swriter/guide/auto_off.html">关闭自动更正</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/auto_spellcheck.html">自动检查拼写</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/number_date_conv.html">打开或关闭表格中的数字识别</a></li>\
-    <li><a target="_top" href="zh-CN/text/swriter/guide/using_hyphen.html">断字</a></li>\
+    <li><a target="_top" href="zh-CN/text/swriter/guide/using_hyphen.html">断词</a></li>\
 		</ul></li>\
     <li><input type="checkbox" id="0215"><label for="0215">项目符号与编号</label><ul>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/captions_numbers.html">向标题添加章节编号</a></li>\
@@ -1049,7 +1049,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/shared/01/02100001.html">正则表达式列表</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="06"><label for="06">HTML 文档</label><ul>\
+    <ul><li><input type="checkbox" id="06"><label for="06">HTML 文档 (Writer Web)</label><ul>\
     <li><a target="_top" href="zh-CN/text/shared/07/09000000.html">网页</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/02/01170700.html">HTML 筛选器和窗体</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/send2html.html">以 HTML 格式保存文本文档</a></li>\
